@@ -78,7 +78,7 @@ def migrate_default(inst):
     @return:
     """
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", '%s.settings' % inst.name)
-    call_command('migratedb', interactive=False, verbosity=0)
+    call_command('migrated', interactive=False, verbosity=0)
 
 def create_default(inst):
     """
