@@ -3,7 +3,7 @@ DBHOST = '127.0.0.1'
 DBPORT = ''
 DBUSER = ''
 DBPASS = ''
-DBNAME = 'django_backstage.sq3'
+DBNAME = 'db/django_backstage.sq3'
 
 DATABASES = {}
 DATABASES['default'] = {
